@@ -1,24 +1,24 @@
-use std::sync::Arc;
 use gio::prelude::*;
+use std::sync::Arc;
 
 mod audio;
-mod ui;
 mod globals;
+mod ui;
 mod utils;
 
 use audio::hal::Hal;
-use audio::sources::metronome::{Metronome, MetronomeHandle};
-use audio::sources::synthesizer::{Synthesizer, SynthesizerHandle};
-use audio::sources::mixer::{Mixer, MixerHandle};
+use audio::sources::metronome::{self, Metronome};
+use audio::sources::mixer::{self, Mixer};
+use audio::sources::synthesizer::{self, Synthesizer};
 
 pub struct AudioContext {
     _hal: Hal,
     _synthesizer_id: usize,
     metronome_id: usize,
-    mixer: MixerHandle,
-    synthesizer: SynthesizerHandle,
-    metronome: MetronomeHandle,
-} 
+    mixer: mixer::Handle,
+    synthesizer: synthesizer::Handle,
+    metronome: metronome::Handle,
+}
 
 fn main() {
     // Initialize audio
@@ -45,8 +45,7 @@ fn main() {
     });
 
     // Initialize UI
-    let app = gtk::Application::new(Some(globals::APP_ID), Default::default())
-        .expect("Failed to init GTK application");
+    let app = gtk::Application::new(Some(globals::APP_ID), gio::ApplicationFlags::default());
     app.connect_activate(move |app| ui::init(app, audio_context.clone()));
-    app.run(&std::env::args().collect::<Vec<_>>());
+    app.run_with_args(&std::env::args().collect::<Vec<_>>());
 }
