@@ -1,4 +1,3 @@
-
 pub struct Tracked<T> {
     value: T,
     updated: bool,
@@ -6,7 +5,10 @@ pub struct Tracked<T> {
 
 impl<T: PartialEq> Tracked<T> {
     pub fn new(value: T) -> Self {
-        Self { value, updated: false }
+        Self {
+            value,
+            updated: false,
+        }
     }
 
     pub fn set(&mut self, value: T) {
@@ -33,4 +35,4 @@ impl<T: PartialEq> Tracked<T> {
             None
         }
     }
-}
\ No newline at end of file
+}
