@@ -1,7 +1,7 @@
+use crossbeam_channel::{self, Sender};
+use lazy_static::lazy_static;
 use std::thread;
 use std::time::Instant;
-use crossbeam_channel::{self,Sender};
-use lazy_static::lazy_static;
 
 const CHANNEL_SIZE: usize = 1024;
 
@@ -10,15 +10,13 @@ lazy_static! {
 }
 
 fn create_logger() -> Sender<Message> {
-    let (tx,rx) = crossbeam_channel::bounded(CHANNEL_SIZE);
-    thread::spawn(move || {
-        loop {
-            match rx.recv() {
-                Ok(Message::Plain(text)) => println!("{}", text),
-                Ok(Message::WithTimestampMs(text, time)) => println!("[{:6} ms] {}", time, text),
-                Ok(Message::WithTimestampUs(text, time)) => println!("[{:9} us] {}", time, text),
-                Err(error) => eprintln!("LOGGER ERROR: Failed to receive log:\n\"{}\"", error),
-            }
+    let (tx, rx) = crossbeam_channel::bounded(CHANNEL_SIZE);
+    thread::spawn(move || loop {
+        match rx.recv() {
+            Ok(Message::Plain(text)) => println!("{}", text),
+            Ok(Message::WithTimestampMs(text, time)) => println!("[{:6} ms] {}", time, text),
+            Ok(Message::WithTimestampUs(text, time)) => println!("[{:9} us] {}", time, text),
+            Err(error) => eprintln!("LOGGER ERROR: Failed to receive log:\n\"{}\"", error),
         }
     });
     tx
@@ -38,20 +36,21 @@ pub fn log(message: Message) {
     }
 }
 
-
 #[allow(dead_code)]
 pub struct TimeLogger {
-    start: Instant
+    start: Instant,
 }
 
 #[allow(dead_code)]
 impl TimeLogger {
     pub fn new() -> Self {
-        Self { start: Instant::now() }
+        Self {
+            start: Instant::now(),
+        }
     }
 
     pub fn log(&self, message: &'static str) {
         let timestamp = self.start.elapsed().as_micros();
         log(Message::WithTimestampUs(message, timestamp));
     }
-}
\ No newline at end of file
+}
